==> aws-cdk-lib-2.0.0-rc.14-sources.jar: software/amazon/awscdk/CfnCodeDeployBlueGreenAdditionalOptions.java <==
package software.amazon.awscdk;

/**
 * (experimental) Additional options for the blue/green deployment.
 * <p>
 * The type of the {&#64;link CfnCodeDeployBlueGreenHookProps.additionalOptions} property.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T10:23:53.780Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.CfnCodeDeployBlueGreenAdditionalOptions")
@software.amazon.jsii.Jsii.Proxy(CfnCodeDeployBlueGreenAdditionalOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface CfnCodeDeployBlueGreenAdditionalOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Specifies time to wait, in minutes, before terminating the blue resources.
     * <p>
     * Default: - 5 minutes
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Number getTerminationWaitTimeInMinutes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnCodeDeployBlueGreenAdditionalOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnCodeDeployBlueGreenAdditionalOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<CfnCodeDeployBlueGreenAdditionalOptions> {
        private java.lang.Number terminationWaitTimeInMinutes;

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenAdditionalOptions#getTerminationWaitTimeInMinutes}
         * @param terminationWaitTimeInMinutes Specifies time to wait, in minutes, before terminating the blue resources.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder terminationWaitTimeInMinutes(java.lang.Number terminationWaitTimeInMinutes) {
            this.terminationWaitTimeInMinutes = terminationWaitTimeInMinutes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCodeDeployBlueGreenAdditionalOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public CfnCodeDeployBlueGreenAdditionalOptions build() {
            return new Jsii$Proxy(terminationWaitTimeInMinutes);
        }
    }

    /**
     * An implementation for {@link CfnCodeDeployBlueGreenAdditionalOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnCodeDeployBlueGreenAdditionalOptions {
        private final java.lang.Number terminationWaitTimeInMinutes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.terminationWaitTimeInMinutes = software.amazon.jsii.Kernel.get(this, "terminationWaitTimeInMinutes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Number terminationWaitTimeInMinutes) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.terminationWaitTimeInMinutes = terminationWaitTimeInMinutes;
        }

        @Override
        public final java.lang.Number getTerminationWaitTimeInMinutes() {
            return this.terminationWaitTimeInMinutes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getTerminationWaitTimeInMinutes() != null) {
                data.set("terminationWaitTimeInMinutes", om.valueToTree(this.getTerminationWaitTimeInMinutes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.CfnCodeDeployBlueGreenAdditionalOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnCodeDeployBlueGreenAdditionalOptions.Jsii$Proxy that = (CfnCodeDeployBlueGreenAdditionalOptions.Jsii$Proxy) o;

            return this.terminationWaitTimeInMinutes != null ? this.terminationWaitTimeInMinutes.equals(that.terminationWaitTimeInMinutes) : that.terminationWaitTimeInMinutes == null;
        }

        @Override
        public final int hashCode() {
            int result = this.terminationWaitTimeInMinutes != null ? this.terminationWaitTimeInMinutes.hashCode() : 0;
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/CfnCodeDeployBlueGreenAdditionalOptions.java <==
package software.amazon.awscdk;

/**
 * Additional options for the blue/green deployment.
 * <p>
 * The type of the {&#64;link CfnCodeDeployBlueGreenHookProps.additionalOptions} property.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.*;
 * CfnCodeDeployBlueGreenAdditionalOptions cfnCodeDeployBlueGreenAdditionalOptions = CfnCodeDeployBlueGreenAdditionalOptions.builder()
 *         .terminationWaitTimeInMinutes(123)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:06.761Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.CfnCodeDeployBlueGreenAdditionalOptions")
@software.amazon.jsii.Jsii.Proxy(CfnCodeDeployBlueGreenAdditionalOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnCodeDeployBlueGreenAdditionalOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Specifies time to wait, in minutes, before terminating the blue resources.
     * <p>
     * Default: - 5 minutes
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getTerminationWaitTimeInMinutes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnCodeDeployBlueGreenAdditionalOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnCodeDeployBlueGreenAdditionalOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnCodeDeployBlueGreenAdditionalOptions> {
        java.lang.Number terminationWaitTimeInMinutes;

        /**
         * Sets the value of {@link CfnCodeDeployBlueGreenAdditionalOptions#getTerminationWaitTimeInMinutes}
         * @param terminationWaitTimeInMinutes Specifies time to wait, in minutes, before terminating the blue resources.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder terminationWaitTimeInMinutes(java.lang.Number terminationWaitTimeInMinutes) {
            this.terminationWaitTimeInMinutes = terminationWaitTimeInMinutes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCodeDeployBlueGreenAdditionalOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnCodeDeployBlueGreenAdditionalOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnCodeDeployBlueGreenAdditionalOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnCodeDeployBlueGreenAdditionalOptions {
        private final java.lang.Number terminationWaitTimeInMinutes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.terminationWaitTimeInMinutes = software.amazon.jsii.Kernel.get(this, "terminationWaitTimeInMinutes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.terminationWaitTimeInMinutes = builder.terminationWaitTimeInMinutes;
        }

        @Override
        public final java.lang.Number getTerminationWaitTimeInMinutes() {
            return this.terminationWaitTimeInMinutes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getTerminationWaitTimeInMinutes() != null) {
                data.set("terminationWaitTimeInMinutes", om.valueToTree(this.getTerminationWaitTimeInMinutes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.CfnCodeDeployBlueGreenAdditionalOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnCodeDeployBlueGreenAdditionalOptions.Jsii$Proxy that = (CfnCodeDeployBlueGreenAdditionalOptions.Jsii$Proxy) o;

            return this.terminationWaitTimeInMinutes != null ? this.terminationWaitTimeInMinutes.equals(that.terminationWaitTimeInMinutes) : that.terminationWaitTimeInMinutes == null;
        }

        @Override
        public final int hashCode() {
            int result = this.terminationWaitTimeInMinutes != null ? this.terminationWaitTimeInMinutes.hashCode() : 0;
            return result;
        }
    }
}
